@@ -1,4 +1,3 @@
-# $Id: EditFiles.pm 52775 2008-04-02 19:50:10Z wsnyder $
 # See copyright, etc in below POD section.
 ######################################################################
 
@@ -14,7 +13,7 @@ use vars qw ($VERSION $Debug);
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.024';
+$VERSION = '3.040';
 
 #######################################################################
 # CONSTRUCTORS
@@ -80,7 +79,7 @@ sub _read_split_file {
 		die "%Error: Unhandled translate comment: $line\n";
 	    }
 	}
-	    
+
 	(my $l2 = $line) =~ s!//.*$!!;
 	if ($l2 =~ s!.*?\*/!!) {
 	    $commented = 0;
@@ -91,7 +90,7 @@ sub _read_split_file {
 		$commented = 0;
 	    }
 	}
-	
+
 	if (!$commented
 	    && $line =~ /^\s*(module|primitive)\s+([A-Za-z0-9_]+)/) {
 	    !$modname or die "%Error: $filename:$.: module without previous endmodule\n";
@@ -129,7 +128,7 @@ sub _read_split_file {
 	}
     }
     $fh->close;
-    
+
     if (!$ever_module) {
 	print "$basename:1: No module, must be include file: $basemod\n" if $Debug;
 	push @lines, @trailer;
@@ -205,7 +204,7 @@ sub edit_file {
     my $wholefile;
     my $origwholefile;
     {	# Read it
-	my $fh = IO::File->new ("<$params{filename}") 
+	my $fh = IO::File->new ("<$params{filename}")
 	    or croak "%Error: $! $params{filename},";
 	local $/; undef $/;
 	$wholefile = <$fh>;
@@ -221,7 +220,7 @@ sub edit_file {
 	print "  $params{write_filename} (Changed)\n" if $params{verbose};
 	my ($dev,$ino,$mode) = stat($params{write_filename});
 	chmod 0777, $params{filename};
-	
+
 	my $fh = IO::File->new (">$params{write_filename}")
 	    or croak "%Error: $! writing $params{write_filename},";
 	print $fh $wholefile;
@@ -351,9 +350,9 @@ write back.  Often the callback will simply perform a search and replace.
 
 =head1 DISTRIBUTION
 
-Verilog-Perl is part of the L<http://www.veripool.com/> free Verilog EDA
+Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/verilog-perl.html>.
+L<http://www.veripool.org/verilog-perl>.
 
 Copyright 2006-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
