@@ -1,17 +1,15 @@
 # Verilog::Language.pm -- Verilog language keywords, etc
-# $Id: Language.pm 52775 2008-04-02 19:50:10Z wsnyder $
-# Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
 # Copyright 2000-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 ######################################################################
 
 =pod
@@ -164,9 +162,9 @@ strings.  Newlines will be preserved in this process.
 
 =head1 DISTRIBUTION
 
-Verilog-Perl is part of the L<http://www.veripool.com/> free Verilog EDA
+Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/verilog-perl.html>.
+L<http://www.veripool.org/verilog-perl>.
 
 Copyright 2000-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
@@ -180,11 +178,11 @@ Wilson Snyder <wsnyder@wsnyder.org>
 
 L<Verilog-Perl>,
 L<Verilog::EditFiles>
-L<Verilog::Parser>, 
-L<Verilog::ParseSig>, 
+L<Verilog::Parser>,
+L<Verilog::ParseSig>,
 L<Verilog::Getopt>
 
-And the L<http://www.veripool.com/verilog-mode.html>Verilog-Mode package for Emacs.
+And the L<http://www.veripool.org/verilog-mode>Verilog-Mode package for Emacs.
 
 =cut
 ######################################################################
@@ -200,7 +198,7 @@ use Carp;
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.024';
+$VERSION = '3.040';
 
 ######################################################################
 #### Internal Variables
@@ -240,7 +238,7 @@ foreach my $kwd (qw(
 		    alias always_comb always_ff always_latch assert assume
 		    before bind bins binsof bit break byte chandle class
 		    clocking const constraint context continue cover
-		    covergroup coverpoint cross dist do endcass endclocking
+		    covergroup coverpoint cross dist do endclass endclocking
 		    endgroup endinterface endpackage endprogram endproperty
 		    endsequence enum expect export extends extern final
 		    first_match foreach forkjoin iff ignore_bins
@@ -493,7 +491,7 @@ sub split_bus {
 	    if (/^\[/) {
 		$inbra = 1;
 		$pretext[$brnum] .= $_;
-	    } 
+	    }
 	    if (!$inbra) {
 		# Not in bracket, just remember text
 		$pretext[$brnum] .= $_;
@@ -599,7 +597,7 @@ sub split_bus_nocomma {
 	    if (/^\[/) {
 		$inbra = 1;
 		$pretext[$brnum] .= $_;
-	    } 
+	    }
 	    if (!$inbra) {
 		# Not in bracket, just remember text
 		$pretext[$brnum] .= $_;
