@@ -1,17 +1,15 @@
 # Verilog - Verilog Perl Interface
-# $Id: Net.pm 52775 2008-04-02 19:50:10Z wsnyder $
-# Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
 # Copyright 2000-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 ######################################################################
 
 package Verilog::Netlist::Net;
@@ -21,7 +19,7 @@ use Verilog::Netlist;
 use Verilog::Netlist::Subclass;
 @ISA = qw(Verilog::Netlist::Net::Struct
 	Verilog::Netlist::Subclass);
-$VERSION = '3.024';
+$VERSION = '3.040';
 use strict;
 
 ######################################################################
@@ -39,6 +37,7 @@ structs('new',
 	   array	=> '$', #'	# Vector
 	   module	=> '$', #'	# Module entity belongs to
 	   signed	=> '$', #'	# True if signed
+	   value	=> '$', #'	# For parameters, the value of the parameter
 	   # below only after links()
 	   port		=> '$', #'	# Reference to port connected to
 	   msb		=> '$', #'	# MSB of signal (if known)
@@ -134,6 +133,7 @@ sub dump {
 	,"  ",($self->_used_in() ? "I":""),($self->_used_out() ? "O":""),
 	,"  Type:",$self->type(),"  Array:",$self->array()||"";
     print "  ",($self->msb).":".($self->lsb) if defined $self->msb;
+    print "  Value:",$self->value if defined $self->value && $self->value ne '';
     print "\n";
 }
 
@@ -222,6 +222,11 @@ The name of the net.
 
 The C++ or declaration type of the net.  For example "wire" or "parameter".
 
+=item $self->value
+
+If the net's type is 'parameter', the value from the parameter's
+declaration.
+
 =item $self->width
 
 The width of the net in bits.
@@ -250,9 +255,9 @@ Prints debugging information for this net, and all pins driving the net.
 
 =head1 DISTRIBUTION
 
-Verilog-Perl is part of the L<http://www.veripool.com/> free Verilog EDA
+Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/verilog-perl.html>.
+L<http://www.veripool.org/verilog-perl>.
 
 Copyright 2000-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
