@@ -1,15 +1,14 @@
-#$Id: Parser.pm 52775 2008-04-02 19:50:10Z wsnyder $
 ######################################################################
 #
 # Copyright 2001-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 ######################################################################
 
 package Verilog::Parser;
@@ -23,7 +22,7 @@ require DynaLoader;
 use strict;
 use vars qw($VERSION $Debug);
 
-$VERSION = '3.024';
+$VERSION = '3.040';
 
 #$Debug sets the default value for debug.  You're better off with the object method though.
 
@@ -368,34 +367,34 @@ file.
   package MyParser;
   use Verilog::Parser;
   @ISA = qw(Verilog::Parser);
-  
+
   # parse, parse_file, etc are inherited from Verilog::Parser
   sub new {
       my $class = shift;
       #print "Class $class\n";
       my $self = $class->SUPER::new();
-      bless $self, $class; 
+      bless $self, $class;
       return $self;
   }
-  
+
   sub symbol {
       my $self = shift;
       my $token = shift;
-      
+
       $self->{symbols}{$token}++;
   }
-  
+
   sub report {
       my $self = shift;
-  
+
       foreach my $sym (sort keys %{$self->{symbols}}) {
-  	 printf "Symbol %-30s occurs %4d times\n",
-  	 $sym, $self->{symbols}{$sym};
+	 printf "Symbol %-30s occurs %4d times\n",
+	 $sym, $self->{symbols}{$sym};
       }
   }
-  
+
   package main;
-  
+
   my $parser = MyParser->new();
   $parser->parse_file (shift);
   $parser->report();
@@ -414,9 +413,9 @@ of parenthesis are required.  (Use "cell cell();", not "cell cell;".)
 
 =head1 DISTRIBUTION
 
-Verilog-Perl is part of the L<http://www.veripool.com/> free Verilog EDA
+Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/verilog-perl.html>.
+L<http://www.veripool.org/verilog-perl>.
 
 Copyright 2000-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
@@ -429,11 +428,11 @@ Wilson Snyder <wsnyder@wsnyder.org>
 =head1 SEE ALSO
 
 L<Verilog-Perl>,
-L<Verilog::Preproc>, 
-L<Verilog::SigParser>, 
-L<Verilog::Language>, 
-L<Verilog::Netlist>, 
-L<Verilog::Getopt>, 
+L<Verilog::Preproc>,
+L<Verilog::SigParser>,
+L<Verilog::Language>,
+L<Verilog::Netlist>,
+L<Verilog::Getopt>,
 L<vrename>,
 L<vpm>
 L<vppp>
